.. include:: ../README.rst

Command Line Interface
**********************
.. argparse::
   :module: gptsum.cli
   :func: build_parser
   :prog: gptsum

.. toctree::
   :hidden:
   :maxdepth: 1

   api
   contributing
